==> matita_0.4.98.orig.tar.gz: matita-0.4.98/components/tactics/closeCoercionGraph.mli <==
(* Copyright (C) 2005, HELM Team.
 * 
 * This file is part of HELM, an Hypertextual, Electronic
 * Library of Mathematics, developed at the Computer Science
 * Department, University of Bologna, Italy.
 * 
 * HELM is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * HELM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HELM; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA  02111-1307, USA.
 * 
 * For details, see the HELM World-Wide-Web page,
 * http://helm.cs.unibo.it/
 *)

(* This module implements the Coercions transitive closure *)

val close_coercion_graph:
  CoercDb.coerc_carr -> CoercDb.coerc_carr -> UriManager.uri -> int ->
  string (* baseuri *) ->
    (CoercDb.coerc_carr * CoercDb.coerc_carr * UriManager.uri *
      int (* saturations *) * Cic.obj * int (* arity *)) list

exception UnableToCompose

val generate_composite:
  Cic.term -> Cic.term (* t2 *) -> Cic.context -> 
  Cic.metasenv -> CicUniv.universe_graph -> 
  int -> int (* saturations of t1/t2 *) ->
    Cic.term * Cic.metasenv * CicUniv.universe_graph

==> matita_0.5.8.orig.tar.gz: matita-0.5.8/components/tactics/closeCoercionGraph.mli <==
(* Copyright (C) 2005, HELM Team.
 * 
 * This file is part of HELM, an Hypertextual, Electronic
 * Library of Mathematics, developed at the Computer Science
 * Department, University of Bologna, Italy.
 * 
 * HELM is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * HELM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HELM; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA  02111-1307, USA.
 * 
 * For details, see the HELM World-Wide-Web page,
 * http://helm.cs.unibo.it/
 *)

(* This module implements the Coercions transitive closure *)

val close_coercion_graph:
  CoercDb.coerc_carr -> CoercDb.coerc_carr -> UriManager.uri -> int ->
  string (* baseuri *) ->
    (CoercDb.coerc_carr * CoercDb.coerc_carr * UriManager.uri *
      int (* saturations *) * Cic.obj * int (* arity *) * int (* cpos *)) list

exception UnableToCompose

val generate_composite:
  Cic.term -> Cic.term (* t2 *) -> Cic.context -> 
  Cic.metasenv -> CicUniv.universe_graph -> 
  int -> int (* saturations of t1/t2 *) ->
    Cic.term * Cic.metasenv * CicUniv.universe_graph
